==> hubzero-cms-2.0.0_2.0.0.0.orig.tar.gz: hubzero-cms-2.0.0-2.0.0.0/cms/core/components/com_newsletter/tables/mailing.recipient.action.php <==
<?php
/**
 * HUBzero CMS
 *
 * Copyright 2005-2015 Purdue University. All rights reserved.
 *
 * This file is part of: The HUBzero(R) Platform for Scientific Collaboration
 *
 * The HUBzero(R) Platform for Scientific Collaboration (HUBzero) is free
 * software: you can redistribute it and/or modify it under the terms of
 * the GNU Lesser General Public License as published by the Free Software
 * Foundation, either version 3 of the License, or (at your option) any
 * later version.
 *
 * HUBzero is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * HUBzero is a registered trademark of Purdue University.
 *
 * @package   hubzero-cms
 * @author    Christopher Smoak <csmoak@purdue.edu>
 * @copyright Copyright 2005-2015 Purdue University. All rights reserved.
 * @license   http://www.gnu.org/licenses/lgpl-3.0.html LGPLv3
 */

namespace Components\Newsletter\Tables;

/**
 * Table class for recipient actions
 */
class MailingRecipientAction extends \JTable
{
	/**
	 * Constructor
	 *
	 * @param   object  $db  Database Object
	 * @return  void
	 */
	public function __construct(&$db)
	{
		parent::__construct('#__newsletter_mailing_recipient_actions', 'id', $db);
	}

	/**
	 * Get newsletter mailing actions
	 *
	 * @param   integer  $id  ID of mailing action
	 * @return  array
	 */
	public function getActions($id = null)
	{
		$sql = "SELECT * FROM {$this->_tbl}";

		if (isset($id) && $id != '')
		{
			$sql .= " WHERE id=" . $this->_db->quote($id);
		}

		$sql .= " ORDER BY date DESC";
		$this->_db->setQuery($sql);
		return $this->_db->loadObjectList();
	}

	/**
	 * Get unconverted mailing actions
	 *
	 * @return  array
	 */
	public function getUnconvertedActions()
	{
		$sql = "SELECT * FROM {$this->_tbl} WHERE (ipLATITUDE = '' OR ipLATITUDE IS NULL OR ipLONGITUDE = '' OR ipLONGITUDE IS NULL)";
		$this->_db->setQuery($sql);
		return $this->_db->loadObjectList();
	}

	/**
	 * Get mailing actions for mailing ID
	 *
	 * @param   integer  $mailingid  Mailing ID #
	 * @param   string   $action     Mailing Action
	 * @return 	array
	 */
	public function getMailingActions($mailingid, $action = 'open')
	{
		$sql = "SELECT * FROM {$this->_tbl}
				WHERE mailingid=" . $this->_db->quote($mailingid) . "
				AND action=" . $this->_db->quote($action);
		$this->_db->setQuery($sql);
		return $this->_db->loadObjectList();
	}

	/**
	 * Check to see if mailing action already exists for mailing ID and email
	 *
	 * @param   integer  $mailingid  Mailing ID #
	 * @param   string   $email      Email Address
	 * @param   string   $action     Mailing Action
	 * @return  boolean
	 */
	public function actionExistsForMailingAndEmail($mailingid, $email, $action = 'open')
	{
		$sql = "SELECT * FROM {$this->_tbl}
				WHERE mailingid=" . $this->_db->quote($mailingid) ."
				AND email=" . $this->_db->quote($email) . "
				AND action=" . $this->_db->quote($action);
		$this->_db->setQuery($sql);
		$result = $this->_db->loadObject();
		return (is_object($result)) ? true : false;
	}
}

==> hubzero-cms-2.0.0_2.0.0.2.orig.tar.gz: hubzero-cms-2.0.0-2.0.0.2/cms/core/components/com_newsletter/tables/mailing.recipient.action.php <==
<?php
/**
 * HUBzero CMS
 *
 * Copyright 2005-2015 HUBzero Foundation, LLC.
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 *
 * HUBzero is a registered trademark of Purdue University.
 *
 * @package   hubzero-cms
 * @author    Christopher Smoak <csmoak@purdue.edu>
 * @copyright Copyright 2005-2015 HUBzero Foundation, LLC.
 * @license   http://opensource.org/licenses/MIT MIT
 */

namespace Components\Newsletter\Tables;

/**
 * Table class for recipient actions
 */
class MailingRecipientAction extends \JTable
{
	/**
	 * Constructor
	 *
	 * @param   object  $db  Database Object
	 * @return  void
	 */
	public function __construct(&$db)
	{
		parent::__construct('#__newsletter_mailing_recipient_actions', 'id', $db);
	}

	/**
	 * Get newsletter mailing actions
	 *
	 * @param   integer  $id  ID of mailing action
	 * @return  array
	 */
	public function getActions($id = null)
	{
		$sql = "SELECT * FROM {$this->_tbl}";

		if (isset($id) && $id != '')
		{
			$sql .= " WHERE id=" . $this->_db->quote($id);
		}

		$sql .= " ORDER BY date DESC";
		$this->_db->setQuery($sql);
		return $this->_db->loadObjectList();
	}

	/**
	 * Get unconverted mailing actions
	 *
	 * @return  array
	 */
	public function getUnconvertedActions()
	{
		$sql = "SELECT * FROM {$this->_tbl} WHERE (ipLATITUDE = '' OR ipLATITUDE IS NULL OR ipLONGITUDE = '' OR ipLONGITUDE IS NULL)";
		$this->_db->setQuery($sql);
		return $this->_db->loadObjectList();
	}

	/**
	 * Get mailing actions for mailing ID
	 *
	 * @param   integer  $mailingid  Mailing ID #
	 * @param   string   $action     Mailing Action
	 * @return 	array
	 */
	public function getMailingActions($mailingid, $action = 'open')
	{
		$sql = "SELECT * FROM {$this->_tbl}
				WHERE mailingid=" . $this->_db->quote($mailingid) . "
				AND action=" . $this->_db->quote($action);
		$this->_db->setQuery($sql);
		return $this->_db->loadObjectList();
	}

	/**
	 * Check to see if mailing action already exists for mailing ID and email
	 *
	 * @param   integer  $mailingid  Mailing ID #
	 * @param   string   $email      Email Address
	 * @param   string   $action     Mailing Action
	 * @return  boolean
	 */
	public function actionExistsForMailingAndEmail($mailingid, $email, $action = 'open')
	{
		$sql = "SELECT * FROM {$this->_tbl}
				WHERE mailingid=" . $this->_db->quote($mailingid) ."
				AND email=" . $this->_db->quote($email) . "
				AND action=" . $this->_db->quote($action);
		$this->_db->setQuery($sql);
		$result = $this->_db->loadObject();
		return (is_object($result)) ? true : false;
	}
}
